@@ -10,11 +10,11 @@
 
 #include <config-kleopatra.h>
 
-#include "exportgroupscommand.h"
 #include "command_p.h"
+#include "exportgroupscommand.h"
 
-#include <utils/applicationstate.h>
 #include "utils/filedialog.h"
+#include <utils/applicationstate.h>
 
 #include <Libkleo/Algorithm>
 #include <Libkleo/Formatting>
@@ -25,8 +25,8 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-#include <QGpgME/Protocol>
 #include <QGpgME/ExportJob>
+#include <QGpgME/Protocol>
 
 #include <QFileInfo>
 #include <QStandardPaths>
@@ -61,12 +61,12 @@ QString requestFilename(QWidget *parent, const std::vector<KeyGroup> &groups)
 {
     const QString proposedFilename = proposeFilename(groups);
 
-    auto filename = FileDialog::getSaveFileNameEx(
-        parent,
-        i18ncp("@title:window", "Export Certificate Group", "Export Certificate Groups", groups.size()),
-        QStringLiteral("imp"),
-        proposedFilename,
-        i18nc("filename filter like Certificate Groups (*.foo)", "Certificate Groups (*%1)", certificateGroupFileExtension));
+    auto filename =
+        FileDialog::getSaveFileNameEx(parent,
+                                      i18ncp("@title:window", "Export Certificate Group", "Export Certificate Groups", groups.size()),
+                                      QStringLiteral("imp"),
+                                      proposedFilename,
+                                      i18nc("filename filter like Certificate Groups (*.foo)", "Certificate Groups (*%1)", certificateGroupFileExtension));
     if (!filename.isEmpty()) {
         const QFileInfo fi{filename};
         if (fi.suffix().isEmpty()) {
@@ -87,12 +87,14 @@ class ExportGroupsCommand::Private : public Command::Private
     {
         return static_cast<ExportGroupsCommand *>(q);
     }
+
 public:
     explicit Private(ExportGroupsCommand *qq);
     ~Private() override;
 
     void start();
 
+    bool confirmExport();
     bool exportGroups();
     bool startExportJob(GpgME::Protocol protocol, const std::vector<Key> &keys);
 
@@ -135,33 +137,27 @@ void ExportGroupsCommand::Private::start()
         return;
     }
 
+    if (!confirmExport()) {
+        canceled();
+        return;
+    }
+
     filename = requestFilename(parentWidgetOrView(), groups);
     if (filename.isEmpty()) {
         canceled();
         return;
     }
 
-    const auto groupKeys = std::accumulate(std::begin(groups), std::end(groups),
-                                           KeyGroup::Keys{},
-                                           [](auto allKeys, const auto &group) {
-                                                const auto keys = group.keys();
-                                                allKeys.insert(std::begin(keys), std::end(keys));
-                                                return allKeys;
-                                           });
-
-    std::vector<Key> openpgpKeys;
-    std::vector<Key> cmsKeys;
-    std::partition_copy(std::begin(groupKeys), std::end(groupKeys),
-                        std::back_inserter(openpgpKeys),
-                        std::back_inserter(cmsKeys),
-                        [](const GpgME::Key &key) {
-                            return key.protocol() == GpgME::OpenPGP;
-                        });
+    const auto groupKeys = std::accumulate(std::begin(groups), std::end(groups), KeyGroup::Keys{}, [](auto allKeys, const auto &group) {
+        const auto keys = group.keys();
+        allKeys.insert(std::begin(keys), std::end(keys));
+        return allKeys;
+    });
+    const auto keys = Kleo::partitionKeysByProtocol(groupKeys);
 
     // remove/overwrite existing file
     if (QFile::exists(filename) && !QFile::remove(filename)) {
-        error(xi18n("Cannot overwrite existing <filename>%1</filename>.", filename),
-              i18nc("@title:window", "Export Failed"));
+        error(xi18n("Cannot overwrite existing <filename>%1</filename>.", filename), i18nc("@title:window", "Export Failed"));
         finished();
         return;
     }
@@ -169,25 +165,71 @@ void ExportGroupsCommand::Private::start()
         finished();
         return;
     }
-    if (!openpgpKeys.empty()) {
-        if (!startExportJob(GpgME::OpenPGP, openpgpKeys)) {
+    if (!keys.openpgp.empty()) {
+        if (!startExportJob(GpgME::OpenPGP, keys.openpgp)) {
             finished();
             return;
         }
     }
-    if (!cmsKeys.empty()) {
-        if (!startExportJob(GpgME::CMS, cmsKeys)) {
+    if (!keys.cms.empty()) {
+        if (!startExportJob(GpgME::CMS, keys.cms)) {
             finishedIfLastJob(nullptr);
         }
     }
 }
 
+bool ExportGroupsCommand::Private::confirmExport()
+{
+    auto notFullyCertifiedGroups = std::accumulate(groups.cbegin(), groups.cend(), QStringList{}, [](auto groupNames, const auto &group) {
+        const bool allOpenPGPKeysAreCertifiedByUser = Kleo::all_of(group.keys(), [](const Key &key) {
+            // we only check the primary user ID of OpenPGP keys because currently group certification only certifies the primary user ID
+            return key.protocol() != GpgME::OpenPGP || Kleo::userIDIsCertifiedByUser(key.userID(0));
+        });
+        if (!allOpenPGPKeysAreCertifiedByUser) {
+            groupNames.push_back(group.name());
+        }
+        return groupNames;
+    });
+    if (!notFullyCertifiedGroups.empty()) {
+        if (groups.size() == 1) {
+            const auto answer = KMessageBox::warningContinueCancel( //
+                parentWidgetOrView(),
+                xi18nc("@info",
+                       "<para>You haven't certified all OpenPGP certificates in this group "
+                       "with an exportable certification. People relying on your certifications "
+                       "may not be able to verify the certificates.</para>"
+                       "<para>Do you want to continue the export?</para>"),
+                i18nc("@title:window", "Confirm Group Export"),
+                KGuiItem{i18nc("@action:button", "Export Group")},
+                KStandardGuiItem::cancel(),
+                QStringLiteral("confirm-export-of-uncertified-groups"));
+            return answer == KMessageBox::Continue;
+        } else {
+            std::sort(notFullyCertifiedGroups.begin(), notFullyCertifiedGroups.end());
+            const auto answer = KMessageBox::warningContinueCancelList( //
+                parentWidgetOrView(),
+                xi18nc("@info",
+                       "<para>You haven't certified all OpenPGP certificates in the groups listed below "
+                       "with exportable certifications. People relying on your certifications "
+                       "may not be able to verify the certificates.</para>"
+                       "<para>Do you want to continue the export?</para>"),
+                notFullyCertifiedGroups,
+                i18nc("@title:window", "Confirm Group Export"),
+                KGuiItem{i18nc("@action:button", "Export Groups")},
+                KStandardGuiItem::cancel(),
+                QStringLiteral("confirm-export-of-uncertified-groups"));
+            return answer == KMessageBox::Continue;
+        }
+    }
+
+    return true;
+}
+
 bool ExportGroupsCommand::Private::exportGroups()
 {
     const auto result = writeKeyGroups(filename, groups);
     if (result != WriteKeyGroups::Success) {
-        error(xi18n("Writing groups to file <filename>%1</filename> failed.", filename),
-              i18nc("@title:window", "Export Failed"));
+        error(xi18n("Writing groups to file <filename>%1</filename> failed.", filename), i18nc("@title:window", "Export Failed"));
     }
     return result == WriteKeyGroups::Success;
 }
@@ -196,21 +238,14 @@ bool ExportGroupsCommand::Private::startExportJob(GpgME::Protocol protocol, cons
 {
     const QGpgME::Protocol *const backend = (protocol == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     Q_ASSERT(backend);
-    std::unique_ptr<ExportJob> jobOwner(backend->publicKeyExportJob(/*armor=*/ true));
+    std::unique_ptr<ExportJob> jobOwner(backend->publicKeyExportJob(/*armor=*/true));
     auto job = jobOwner.get();
     Q_ASSERT(job);
 
-    connect(job, &ExportJob::result,
-            q, [this, job](const GpgME::Error &err, const QByteArray &keyData) {
-                onExportJobResult(job, err, keyData);
-            });
-#if QGPGME_JOB_HAS_NEW_PROGRESS_SIGNALS
-    connect(job, &QGpgME::Job::jobProgress,
-            q, &Command::progress);
-#else
-    connect(job, &QGpgME::Job::progress,
-            q, [this](const QString &, int current, int total) { Q_EMIT q->progress(current, total); });
-#endif
+    connect(job, &ExportJob::result, q, [this, job](const GpgME::Error &err, const QByteArray &keyData) {
+        onExportJobResult(job, err, keyData);
+    });
+    connect(job, &QGpgME::Job::jobProgress, q, &Command::progress);
 
     const GpgME::Error err = job->start(Kleo::getFingerprints(keys));
     if (err) {
@@ -235,16 +270,14 @@ void ExportGroupsCommand::Private::onExportJobResult(const QGpgME::Job *job, con
 
     QFile f{filename};
     if (!f.open(QIODevice::WriteOnly | QIODevice::Append)) {
-        error(xi18n("Cannot open file <filename>%1</filename> for writing.", filename),
-              i18nc("@title:window", "Export Failed"));
+        error(xi18n("Cannot open file <filename>%1</filename> for writing.", filename), i18nc("@title:window", "Export Failed"));
         finishedIfLastJob(job);
         return;
     }
 
     const auto bytesWritten = f.write(keyData);
     if (bytesWritten != keyData.size()) {
-        error(xi18n("Writing certificates to file <filename>%1</filename> failed.", filename),
-              i18nc("@title:window", "Export Failed"));
+        error(xi18n("Writing certificates to file <filename>%1</filename> failed.", filename), i18nc("@title:window", "Export Failed"));
     }
 
     finishedIfLastJob(job);
@@ -270,12 +303,11 @@ void ExportGroupsCommand::Private::finishedIfLastJob(const QGpgME::Job *job)
 
 void ExportGroupsCommand::Private::cancelJobs()
 {
-    std::for_each(std::cbegin(exportJobs), std::cend(exportJobs),
-                  [](const auto &job) {
-                      if (job) {
-                          job->slotCancel();
-                      }
-                  });
+    std::for_each(std::cbegin(exportJobs), std::cend(exportJobs), [](const auto &job) {
+        if (job) {
+            job->slotCancel();
+        }
+    });
     exportJobs.clear();
 }
 
