@@ -7,44 +7,28 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <config-kleopatra.h>
 #include "gnupgsystemconfigurationpage.h"
+#include <config-kleopatra.h>
 
 #include <Libkleo/CryptoConfigModule>
-#include <QGpgME/Protocol>
 #include <QGpgME/CryptoConfig>
+#include <QGpgME/Protocol>
 
 #include <QVBoxLayout>
 
 using namespace Kleo::Config;
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-GnuPGSystemConfigurationPage::GnuPGSystemConfigurationPage(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-GnuPGSystemConfigurationPage::GnuPGSystemConfigurationPage(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+GnuPGSystemConfigurationPage::GnuPGSystemConfigurationPage(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QVBoxLayout(this);
-#else
     auto lay = new QVBoxLayout(widget());
-#endif
     lay->setContentsMargins(0, 0, 0, 0);
 
     QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
 
-    mWidget = new CryptoConfigModule(config,
-                                     CryptoConfigModule::TabbedLayout,
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-                                     this);
-#else
-                                     widget());
-#endif
+    mWidget = new CryptoConfigModule(config, CryptoConfigModule::TabbedLayout, widget());
     lay->addWidget(mWidget);
 
-
     connect(mWidget, &CryptoConfigModule::changed, this, &Kleo::Config::GnuPGSystemConfigurationPage::markAsChanged);
 }
 
@@ -76,3 +60,5 @@ void GnuPGSystemConfigurationPage::defaults()
 {
     mWidget->defaults();
 }
+
+#include "moc_gnupgsystemconfigurationpage.cpp"
