@@ -16,8 +16,8 @@
 
 #include <gpgme++/global.h>
 
-#include <memory>
 #include <QPointer>
+#include <memory>
 
 namespace Kleo
 {
@@ -87,7 +87,10 @@ private:
 class Task::Result
 {
     const QString m_nonce;
+
 public:
+    class Content;
+
     Result();
     virtual ~Result();
 
@@ -103,7 +106,13 @@ public:
         Warning,
         Danger,
         NeutralSuccess,
-        NeutralError
+        NeutralError,
+    };
+
+    enum class ContentType {
+        None,
+        Mime,
+        Mbox,
     };
 
     virtual QString icon() const;
@@ -113,7 +122,11 @@ public:
     virtual QString errorString() const = 0;
     virtual VisualCode code() const = 0;
     virtual AuditLogEntry auditLog() const = 0;
-    virtual QPointer<Task> parentTask() const {return QPointer<Task>();}
+    virtual QPointer<Task> parentTask() const
+    {
+        return QPointer<Task>();
+    }
+    virtual ContentType viewableContentType() const;
 
 protected:
     static QString iconPath(VisualCode code);
@@ -123,8 +136,5 @@ private:
     class Private;
     kdtools::pimpl_ptr<Private> d;
 };
-
 }
 }
-
-
