@@ -69,8 +69,9 @@ public:
         ui.treeView->view()->setSelectionMode(QAbstractItemView::SingleSelection);
         ui.treeView->setFlatModel(AbstractKeyListModel::createFlatKeyListModel(ui.treeView));
         ui.treeView->setHierarchicalView(false);
-        connect(ui.treeView->view(), &QAbstractItemView::doubleClicked,
-                q, [this] (const QModelIndex &index) { showKeyDetails(index); });
+        connect(ui.treeView->view(), &QAbstractItemView::doubleClicked, q, [this](const QModelIndex &index) {
+            showKeyDetails(index);
+        });
         mainLayout->addWidget(ui.treeView);
 
         ui.buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
@@ -94,7 +95,7 @@ public:
 private:
     void saveLayout()
     {
-        KConfigGroup configGroup(KSharedConfig::openStateConfig(), "GroupDetailsDialog");
+        KConfigGroup configGroup(KSharedConfig::openStateConfig(), QStringLiteral("GroupDetailsDialog"));
         ui.treeView->saveLayout(configGroup);
         configGroup.writeEntry("Size", q->size());
         configGroup.sync();
@@ -102,7 +103,7 @@ private:
 
     void restoreLayout(const QSize &defaultSize)
     {
-        const KConfigGroup configGroup(KSharedConfig::openStateConfig(), "GroupDetailsDialog");
+        const KConfigGroup configGroup(KSharedConfig::openStateConfig(), QStringLiteral("GroupDetailsDialog"));
         ui.treeView->restoreLayout(configGroup);
         const QSize size = configGroup.readEntry("Size", defaultSize);
         if (size.isValid()) {
@@ -154,3 +155,5 @@ void GroupDetailsDialog::setGroup(const KeyGroup &group)
     const KeyGroup::Keys &keys = group.keys();
     d->ui.treeView->setKeys(std::vector<GpgME::Key>(keys.cbegin(), keys.cend()));
 }
+
+#include "moc_groupdetailsdialog.cpp"
