@@ -5,10 +5,11 @@
 
 #pragma once
 
-#include <QWidget>
 #include <QDialog>
+#include <QWidget>
 
-namespace GpgME {
+namespace GpgME
+{
 class Key;
 }
 
@@ -17,7 +18,7 @@ class SubKeysWidget : public QWidget
     Q_OBJECT
 public:
     explicit SubKeysWidget(QWidget *parent = nullptr);
-    ~SubKeysWidget();
+    ~SubKeysWidget() override;
 
     void setKey(const GpgME::Key &key);
     GpgME::Key key() const;
@@ -27,13 +28,12 @@ private:
     const QScopedPointer<Private> d;
 };
 
-
 class SubKeysDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit SubKeysDialog(QWidget *parent = nullptr);
-    ~SubKeysDialog();
+    ~SubKeysDialog() override;
 
     void setKey(const GpgME::Key &key);
     GpgME::Key key() const;
@@ -42,4 +42,3 @@ private:
     void readConfig();
     void writeConfig();
 };
-
