@@ -22,10 +22,11 @@
 
 extern QElapsedTimer startupTimer;
 #define STARTUP_TIMING qCDebug(KLEOPATRA_LOG) << "Startup timing:" << startupTimer.elapsed() << "ms:"
-#define STARTUP_TRACE  qCDebug(KLEOPATRA_LOG) << "Startup timing:" << startupTimer.elapsed() << "ms:" << SRCNAME << __func__ << __LINE__;
+#define STARTUP_TRACE qCDebug(KLEOPATRA_LOG) << "Startup timing:" << startupTimer.elapsed() << "ms:" << SRCNAME << __func__ << __LINE__;
 
 class MainWindow;
 class SysTrayIcon;
+class QSettings;
 
 class KleopatraApplication : public QApplication
 {
@@ -62,8 +63,7 @@ public:
      *
      * @returns an empty QString on success. A localized error message otherwise.
      * */
-    QString newInstance(const QCommandLineParser &parser,
-                        const QString &workingDirectory = QString());
+    QString newInstance(const QCommandLineParser &parser, const QString &workingDirectory = QString());
 
     void setMainWindow(MainWindow *mw);
 
@@ -79,6 +79,10 @@ public:
     void restoreMainWindow();
     void openConfigDialogWithForeignParent(WId parentWId);
 
+    /* Add optional signed settings for specialized distributions */
+    void setDistributionSettings(const std::shared_ptr<QSettings> &settings);
+    std::shared_ptr<QSettings> distributionSettings() const;
+
 public Q_SLOTS:
     void openOrRaiseMainWindow();
     void openOrRaiseConfigDialog();
@@ -111,4 +115,3 @@ private:
     class Private;
     kdtools::pimpl_ptr<Private> d;
 };
-
