@@ -1,5 +1,4 @@
-#ifndef SMARTCARD_NETKEYCARD_H
-#define SMARTCARD_NETKEYCARD_H
+#pragma once
 /*  smartcard/netkeycard.h
 
     This file is part of Kleopatra, the KDE keymanager
@@ -19,7 +18,7 @@ namespace SmartCard
 struct KeyPairInfo;
 
 /** Class to work with NetKey smartcards or compatible tokens */
-class NetKeyCard: public Card
+class NetKeyCard : public Card
 {
 public:
     explicit NetKeyCard(const Card &card);
@@ -29,21 +28,17 @@ public:
     static std::string nksPinKeyRef();
     static std::string sigGPinKeyRef();
 
-    void setCardInfo(const std::vector< std::pair<std::string, std::string> > &infos);
-
     bool hasSigGNullPin() const;
     bool hasNKSNullPin() const;
 
-    std::vector <GpgME::Key> keys() const;
+    std::vector<GpgME::Key> keys() const;
 
 private:
+    void processCardInfo() override;
     void setKeyPairInfo(const std::vector<KeyPairInfo> &infos);
 
 private:
-    std::vector <GpgME::Key> mKeys;
+    std::vector<GpgME::Key> mKeys;
 };
 } // namespace Smartcard
 } // namespace Kleopatra
-
-#endif // SMARTCARD_CARD_H
-
