@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UISERVER_VERIFYCOMMAND_H__
-#define __KLEOPATRA_UISERVER_VERIFYCOMMAND_H__
+#pragma once
 
 #include "assuancommand.h"
 
@@ -19,7 +18,7 @@ namespace Kleo
 class VerifyCommand : public AssuanCommandMixin<VerifyCommand, DecryptVerifyCommandEMailBase>
 {
 public:
-    //VerifyCommand();
+    // VerifyCommand();
     //~VerifyCommand();
 
 private:
@@ -31,6 +30,7 @@ private:
     {
         return EMail;
     }
+
 public:
     static const char *staticName()
     {
@@ -39,5 +39,3 @@ public:
 };
 
 }
-
-#endif // __KLEOPATRA_UISERVER_VERIFYCOMMAND_H__
